@@ -138,7 +138,7 @@ class dyn_obj:
             for i in range(len(frames)):
                 cur_frame = frames[i]
                 
-                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]) * cur_frame
+                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]-1) * cur_frame
                 bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
 
 class dyn_vec:
@@ -160,6 +160,7 @@ class dyn_vec:
         
         self.scale = scale_mag
         vec.scale = (scale_mag, scale_off, scale_off)
+        self.anim = anim
         
         self.frames = anim.frames
     def animate(self, x, y, z):
@@ -180,7 +181,7 @@ class dyn_vec:
         norm_y = y/max_y *self.scale
         norm_z = z/max_z *self.scale
         
-        self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent, anim)
+        self.point_rf = ref_frame(self.name+"_pointing_empty", self.parent, self.anim)
         
         tracking_constraint = self.parent_rf.ob.constraints.new('DAMPED_TRACK')
         tracking_constraint.target = self.point_rf.ob
